@@ -1,12 +1,18 @@
 """A Django app for adding object tools for models in the admin."""
 
-__version__ = "4.3.0"
+__version__ = "5.0.0"
 
 
-# kind of like __all__, make these available for public
 from .utils import (
     BaseDjangoObjectActions,
     DjangoObjectActions,
-    takes_instance_or_queryset,
     action,
+    takes_instance_or_queryset,
 )
+
+__all__ = [
+    "BaseDjangoObjectActions",
+    "DjangoObjectActions",
+    "action",
+    "takes_instance_or_queryset",
+]
