@@ -2,24 +2,26 @@
 Integration tests that actually try and use the tools setup in admin.py
 """
 
+from unittest.mock import patch
+
 from django.contrib.admin.utils import quote
 from django.http import HttpResponse
 from django.urls import reverse
-from unittest.mock import patch
 
-from .tests import LoggedInTestCase
 from example_project.polls.factories import (
     CommentFactory,
     PollFactory,
     RelatedDataFactory,
 )
 
+from .tests import LoggedInTestCase
+
 
 class CommentTests(LoggedInTestCase):
     def test_action_on_a_model_with_uuid_pk_works(self):
         comment = CommentFactory()
         comment_url = reverse("admin:polls_comment_change", args=(comment.pk,))
-        action_url = "/admin/polls/comment/{0}/actions/hodor/".format(comment.pk)
+        action_url = f"/admin/polls/comment/{comment.pk}/actions/hodor/"
         # sanity check that url has a uuid
         self.assertIn("-", action_url)
         response = self.client.get(action_url)
@@ -28,7 +30,7 @@ class CommentTests(LoggedInTestCase):
     @patch("django_object_actions.utils.ChangeActionView.dispatch")
     def test_action_on_a_model_with_arbitrary_pk_works(self, mock_view):
         mock_view.return_value = HttpResponse()
-        action_url = "/admin/polls/comment/{0}/actions/hodor/".format(" i am a pk ")
+        action_url = "/admin/polls/comment/{}/actions/hodor/".format(" i am a pk ")
 
         self.client.get(action_url)
 
@@ -38,7 +40,7 @@ class CommentTests(LoggedInTestCase):
     @patch("django_object_actions.utils.ChangeActionView.dispatch")
     def test_action_on_a_model_with_slash_in_pk_works(self, mock_view):
         mock_view.return_value = HttpResponse()
-        action_url = "/admin/polls/comment/{0}/actions/hodor/".format("pk/slash")
+        action_url = "/admin/polls/comment/{}/actions/hodor/".format("pk/slash")
 
         self.client.get(action_url)
 
@@ -52,8 +54,8 @@ class ExtraTests(LoggedInTestCase):
         related_data_url = reverse(
             "admin:polls_relateddata_change", args=(related_data.pk,)
         )
-        action_url = "/admin/polls/relateddata/{}/actions/fill_up/".format(
-            quote(related_data.pk)
+        action_url = (
+            f"/admin/polls/relateddata/{quote(related_data.pk)}/actions/fill_up/"
         )
 
         response = self.client.get(action_url)
