@@ -43,18 +43,12 @@ class CommentFactory(factory.django.DjangoModelFactory):
 
 def get_random_string(length):
     letters = string.ascii_lowercase
-    result_str = "".join(random.choice(letters) for i in range(length))
-    return result_str
+    return "".join(random.choice(letters) for i in range(length))
 
 
 class RelatedDataFactory(factory.django.DjangoModelFactory):
     id = factory.lazy_attribute(
-        lambda __: "{}:{}-{}!{}".format(
-            get_random_string(2),
-            get_random_string(2),
-            get_random_string(2),
-            get_random_string(2),
-        )
+        lambda __: f"{get_random_string(2)}:{get_random_string(2)}-{get_random_string(2)}!{get_random_string(2)}"
     )
 
     class Meta:
