@@ -1,8 +1,7 @@
-from django import VERSION
-from django.urls import include, path
 from django.contrib import admin
-from example_project.polls.admin import support_admin
+from django.urls import path
 
+from example_project.polls.admin import support_admin
 
 urlpatterns = [
     path("admin/", admin.site.urls),
